@@ -327,6 +327,11 @@ class WebController(BaseController):
 		Returns:
 			HTTP response with headers
 		"""
+
+		text = getUrlArg(request, "text", "")
+		if text:
+			return remoteControl(0, "text", text)  # text input do not need type and command
+
 		res = self.testMandatoryArguments(request, ["command"])
 		if res:
 			return res
@@ -518,10 +523,10 @@ class WebController(BaseController):
 		"""
 		bRef = getUrlArg(request, "bRef", "")
 		request.setHeader('Content-Type', 'application/xspf+xml')
-		bname = getUrlArg(request, "bname")
-		if bname != None:
-			bname = bname.replace(",", "_").replace(";", "_")
-			request.setHeader('Content-Disposition', 'inline; filename=%s.%s;' % (bname, 'xspf'))
+		bouquetName = getUrlArg(request, "bName")
+		if bouquetName != None:
+			bouquetName = bouquetName.replace(",", "_").replace(";", "_")
+			request.setHeader('Content-Disposition', 'inline; filename=%s.%s;' % (bouquetName, 'xspf'))
 		services = getServices(bRef, False)
 		if comp_config.OpenWebif.auth_for_streaming.value:
 			session = GetSession()
@@ -534,7 +539,7 @@ class WebController(BaseController):
 		portNumber = comp_config.OpenWebif.streamport.value
 		services["host"] = "%s:%s" % (request.getRequestHostname(), portNumber)
 		services["auth"] = auth
-		services["bname"] = bname
+		services["bname"] = bouquetName
 		return services
 
 	def P_servicesm3u(self, request):
@@ -557,10 +562,10 @@ class WebController(BaseController):
 		"""
 		bRef = getUrlArg(request, "bRef", "")
 		request.setHeader('Content-Type', 'application/x-mpegurl')
-		bname = getUrlArg(request, "bname")
-		if bname != None:
-			bname = bname.replace(",", "_").replace(";", "_")
-			request.setHeader('Content-Disposition', 'inline; filename=%s.%s;' % (bname, 'm3u8'))
+		bouquetName = getUrlArg(request, "bName")
+		if bouquetName != None:
+			bouquetName = bouquetName.replace(",", "_").replace(";", "_")
+			request.setHeader('Content-Disposition', 'inline; filename=%s.%s;' % (bouquetName, 'm3u8'))
 		services = getServices(bRef, False)
 		if comp_config.OpenWebif.auth_for_streaming.value:
 			session = GetSession()
@@ -916,7 +921,8 @@ class WebController(BaseController):
 			_deltag = getUrlArg(request, "deltag")
 			_title = getUrlArg(request, "title")
 			_cuts = getUrlArg(request, "cuts")
-			return getMovieInfo(_sRef, _addtag, _deltag, _title, _cuts, True)
+			_desc = getUrlArg(request, "desc")
+			return getMovieInfo(_sRef, _addtag, _deltag, _title, _cuts, _desc ,True)
 		else:
 			return getMovieInfo()
 
@@ -2214,6 +2220,8 @@ class WebController(BaseController):
 		moviedb = comp_config.OpenWebif.webcache.moviedb.value if comp_config.OpenWebif.webcache.moviedb.value else 'IMDb'
 		ret['moviedb'] = moviedb
 		ret['showchanneldetails'] = comp_config.OpenWebif.webcache.showchanneldetails.value
+		smallremote = comp_config.OpenWebif.webcache.smallremote.value if comp_config.OpenWebif.webcache.smallremote.value else 'new'
+		ret['smallremote'] = smallremote
 		return ret
 
 	def P_config(self, request):
@@ -2305,6 +2313,12 @@ class WebController(BaseController):
 			val = (getUrlArg(request, "zapstream") == 'true')
 			comp_config.OpenWebif.webcache.zapstream.value = val
 			comp_config.OpenWebif.webcache.zapstream.save()
+		elif b"smallremote" in list(request.args.keys()):
+			try:
+				comp_config.OpenWebif.webcache.smallremote.value = getUrlArg(request, "smallremote")
+				comp_config.OpenWebif.webcache.smallremote.save()
+			except Exception:
+				pass
 		elif b"theme" in list(request.args.keys()):
 			try:
 				comp_config.OpenWebif.webcache.theme.value = getUrlArg(request, "theme")
